# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-namespace-autoclean
Version:	0.29
Release:	15.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
Summary:	Keep imports out of your namespace
URL:		https://metacpan.org/release/namespace-autoclean
Source0:	https://cpan.metacpan.org/modules/by-module/namespace/namespace-autoclean-%{version}.tar.gz
Patch5:		namespace-autoclean-0.29-pod-spell.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module
BuildRequires:	perl(B::Hooks::EndOfScope) >= 0.12
BuildRequires:	perl(List::Util)
BuildRequires:	perl(namespace::clean) >= 0.20
BuildRequires:	perl(strict)
BuildRequires:	perl(Sub::Identify)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Carp)
BuildRequires:	perl(constant)
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(FindBin)
BuildRequires:	perl(overload)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(Test::More) >= 0.88
BuildRequires:	perl(Test::Needs)
# Optional Tests
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(Class::MOP)
BuildRequires:	perl(CPAN::Meta) >= 2.120900
BuildRequires:	perl(Moo) >= 1.004000
BuildRequires:	perl(Moose) >= 0.56
BuildRequires:	perl(Moose::Role)
BuildRequires:	perl(MooseX::Role::WithOverloading) >= 0.09
BuildRequires:	perl(Sub::Install)
BuildRequires:	perl(Sub::Name)
%endif
# Extra Tests
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(blib)
BuildRequires:	perl(Exporter) >= 5.57
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IPC::Open3)
BuildRequires:	perl(lib)
BuildRequires:	perl(Module::Runtime)
BuildRequires:	perl(MooseX::Role::Parameterized)
BuildRequires:	perl(Mouse) >= 0.40
BuildRequires:	perl(parent)
BuildRequires:	perl(Pod::Coverage::TrustPod)
BuildRequires:	perl(Role::Tiny) >= 1.003000
BuildRequires:	perl(Sub::Exporter)
BuildRequires:	perl(Test::CleanNamespaces) >= 0.15
BuildRequires:	perl(Test::CPAN::Changes) >= 0.19
BuildRequires:	perl(Test::CPAN::Meta)
BuildRequires:	perl(Test::EOL)
BuildRequires:	perl(Test::Fatal)
BuildRequires:	perl(Test::Kwalitee) >= 1.21
BuildRequires:	perl(Test::MinimumVersion)
BuildRequires:	perl(Test::Mojibake)
BuildRequires:	perl(Test::More) >= 0.96
BuildRequires:	perl(Test::NoTabs)
BuildRequires:	perl(Test::Pod) >= 1.41
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
BuildRequires:	perl(Test::Portability::Files)
BuildRequires:	perl(Test::Spelling) >= 0.12, hunspell-en
%endif
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Sub::Identify)

%description
When you import a function into a Perl package, it will naturally also be
available as a method. The 'namespace::autoclean' pragma will remove all
imported symbols at the end of the current package's compile cycle. Functions
called in the package itself will still be bound by their name, but they won't
show up as methods on your class or instances. This module is very similar to
namespace::clean, except it will clean all imported functions, no matter if you
imported them before or after you 'use'd the pragma. It will also not touch
anything that looks like a method.

%prep
%setup -q -n namespace-autoclean-%{version}

# Code examples and apostrophes in Pod can confuse spell checker
%patch -P 5

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

# Author/Release tests
%if 0%{!?perl_bootstrap:1}
prove -Ilib $(echo $(find xt/ -name '*.t' | sort))
%endif

%files
%license LICENCE
%doc Changes CONTRIBUTING README
%{perl_vendorlib}/namespace/
%{_mandir}/man3/namespace::autoclean.3*

%changelog
* Wed May  3 2023 Paul Howarth <paul@city-fan.org> - 0.29-15
- Use SPDX-format license tag
- Avoid use of deprecated patch syntax

* Tue Apr  6 2021 Paul Howarth <paul@city-fan.org> - 0.29-2
- BR: perl(blib) for extra tests
- Use %%license unconditionally

* Mon Aug 26 2019 Paul Howarth <paul@city-fan.org> - 0.29-1
- Update to 0.29
  - Switch from Test::Requires to Test::Needs
  - Report on the installed versions of more optional modules

* Sat Jun  8 2019 Paul Howarth <paul@city-fan.org> - 0.28-16
- Perl 5.30 rebuild

* Thu Apr 26 2018 Paul Howarth <paul@city-fan.org> - 0.28-10
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop workaround for building without Test::Kwalitee ≥ 1.21
  - Drop workarounds for building with Test::More < 0.96
  - Spell check backend is always hunspell

* Tue Jan 10 2017 Paul Howarth <paul@city-fan.org> - 0.28-6
- Test::Kwalitee ≥ 1.21 now available back to Fedora 9

* Fri Sep  9 2016 Paul Howarth <paul@city-fan.org> - 0.28-5
- Fix FTBFS when perl is not in the minimal buildroot
- BR: perl-generators where available
- Simplify find command using -delete

* Tue Oct 13 2015 Paul Howarth <paul@city-fan.org> - 0.28-1
- Update to 0.28
  - Skip failing tests with old Moo or when Sub::Util is broken
    (CPAN RT#107643)
- Update patches as needed

* Wed Sep  9 2015 Paul Howarth <paul@city-fan.org> - 0.27-1
- Update to 0.27
  - Package with only ExtUtils::MakeMaker to ease installation on perl 5.6
- Update patches as needed

* Sun Jun 28 2015 Paul Howarth <paul@city-fan.org> - 0.26-4
- Perl 5.22 rebuild

* Sun Jun  7 2015 Paul Howarth <paul@city-fan.org> - 0.26-1
- Update to 0.26
  - Mark all Mouse tests as TODO below perl 5.010, to enable installation
    despite apparent instability issues (see CPAN RT#101825)
- Update patches as needed

* Sat Jun  6 2015 Paul Howarth <paul@city-fan.org> - 0.25-1
- Update to 0.25
  - Load Moo::Role earlier in a test, to make a potential misconfiguration more
    visible
- Update patches as needed

* Sun Jan  4 2015 Paul Howarth <paul@city-fan.org> - 0.24-1
- Update to 0.24
  - Be more lenient in optional Mouse tests to handle edge cases in older and
    pure perl versions

* Tue Nov  4 2014 Paul Howarth <paul@city-fan.org> - 0.22-1
- Update to 0.22
  - Drop testing of MooseX::MarkAsMethods, now that Moose 2.1400 has better
    overload handling
- Run Moo/Mouse tests on old distributions too
- Update patches as needed

* Tue Sep 23 2014 Paul Howarth <paul@city-fan.org> - 0.20-1
- Update to 0.20
  - Moose earlier than 2.0300 had a broken ->does method, which called methods
    on a class's meta when it might not be initialized (CPAN RT#98424)
- Don't try to run the Kwalitee test unless we have a new enough version of
  Test::Kwalitee
- Update patches as needed

* Mon Sep 15 2014 Paul Howarth <paul@city-fan.org> - 0.19-3
- Perl 5.20 rebuild

* Wed Aug 27 2014 Paul Howarth <paul@city-fan.org> - 0.19-2
- Don't try to run the optional tests when bootstrapping
- Use %%license where possible

* Tue Jun 17 2014 Paul Howarth <paul@city-fan.org> - 0.19-1
- Update to 0.19
  - More comprehensive testing with Moo/Mouse/Moose
  - Fixed cleaning of constants
- Don't skip some tests on Perl 5.8 as they're now working
- Update patches as needed

* Mon Jun 16 2014 Paul Howarth <paul@city-fan.org> - 0.18-1
- Update to 0.18
  - Better method detection for Mouse (GH#4)
- BR: perl(Test::CPAN::Changes) unconditionally
- Update patches as needed

* Wed Jun 11 2014 Paul Howarth <paul@city-fan.org> - 0.17-1
- Update to 0.17
  - Changed the code to no longer _require_ Class::MOP; if your class is not a
    Moose class then we don't load Class::MOP, which was particularly
    problematic for Moo classes, as using namespace::autoclean with a Moo class
    "upgraded" it to be a Moose class
  - Using this module just broke overloading in a class (CPAN RT#50938)
  - Add -except to import options; this allows you to explicitly not clean a
    sub.
- Add patch to support building with Module::Build::Tiny < 0.036
- Update patches as needed
- Update %%description to remove reference to Class::MOP
- Don't run some of the extra tests under Perl 5.8 as they seem to need 5.10
- Drop %%defattr, redundant since rpm 4.4

* Sun Dec 15 2013 Paul Howarth <paul@city-fan.org> - 0.15-1
- Update to 0.15
  - Update configure_requires checking in Makefile.PL, add CONTRIBUTING file
- Update patches as needed

* Wed Oct  9 2013 Paul Howarth <paul@city-fan.org> - 0.14-1
- Update to 0.14
  - Bump dependency on B::Hooks::EndOfScope, to get the separation of pure-perl
    and XS components (CPAN RT#89245)
  - Repository migrated to the github moose organization
- This release by ETHER -> update source URL
- Switch to Module::Build::Tiny flow
- Add build requirements for extra tests and run them except when bootstrapping
- Add a series of patches to support building with old versions of Test::More

* Thu Jul 25 2013 Paul Howarth <paul@city-fan.org> - 0.13-6
- Perl 5.18 rebuild

* Sat Jun 29 2013 Paul Howarth <paul@city-fan.org> - 0.13-5
- Import from Fedora

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.13-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jun 22 2012 Petr Pisar <ppisar@redhat.com> - 0.13-2
- Perl 5.16 rebuild

* Sat Jan 14 2012 Iain Arnell <iarnell@gmail.com> - 0.13-1
- Update to latest upstream version

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.12-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Thu Jul 21 2011 Petr Sabata <contyk@redhat.com> - 0.12-3
- Perl mass rebuild

* Tue Jul 19 2011 Petr Sabata <contyk@redhat.com> - 0.12-2
- Perl mass rebuild

* Sun Mar 13 2011 Iain Arnell <iarnell@gmail.com> 0.12-1
- Update to latest upstream version
- Clean up spec for modern rpmbuild

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.11-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Dec 21 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.11-2
- Rebuild to fixing problems with vendorarch/lib (#661697)

* Tue May 04 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.09-4
- Mass rebuild with perl-5.12.0

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 0.09-3
- Rebuild against perl 5.10.1

* Thu Sep 17 2009 Stepan Kasal <skasal@redhat.com> 0.09-2
- Fix the previous changelog entry

* Wed Sep 16 2009 Chris Weyl <cweyl@alumni.drew.edu> 0.09-1
- Add %%perl_default_filter'ing
- Auto-update to 0.09 (by cpan-spec-update 0.01)
- Added a new req on perl(B::Hooks::EndOfScope) (version 0.07)
- Added a new req on perl(Class::MOP) (version 0.80)
- Added a new req on perl(List::Util) (version 0)
- Added a new req on perl(namespace::clean) (version 0.11)

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.08-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Jul 01 2009 Chris Weyl <cweyl@alumni.drew.edu> 0.08-1
- Submission

* Wed Jul 01 2009 Chris Weyl <cweyl@alumni.drew.edu> 0.08-0
- Initial RPM packaging
- Generated with cpan2dist (CPANPLUS::Dist::RPM version 0.0.8)
